@@ -1,7 +1,7 @@
 // qsamplerOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2004-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2024, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007,2008,2015 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -24,7 +24,9 @@
 #include "qsamplerOptions.h"
 #include "qsamplerMainForm.h"
 
+#include <QFileInfo>
 #include <QTextStream>
+
 #include <QComboBox>
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
@@ -176,7 +178,7 @@ void Options::saveOptions (void)
 {
 	// Make program version available in the future.
 	m_settings.beginGroup("/Program");
-	m_settings.setValue("/Version", CONFIG_BUILD_VERSION);
+	m_settings.setValue("/Version", PROJECT_VERSION);
 	m_settings.endGroup();
 
 	// And go into general options group.
@@ -327,8 +329,6 @@ void Options::print_usage ( const QString& arg0 )
 // Parse command line arguments into m_settings.
 bool Options::parse_args ( const QStringList& args )
 {
-	int iCmdArgs = 0;
-
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
 
 	QCommandLineParser parser;
@@ -371,29 +371,28 @@ bool Options::parse_args ( const QStringList& args )
 		iServerPort = iVal;
 	}
 
-	foreach(const QString& sArg, parser.positionalArguments()) {
-		if (iCmdArgs > 0)
-			sSessionFile += ' ';
-		sSessionFile += sArg;
-		++iCmdArgs;
+	foreach (const QString& sArg, parser.positionalArguments()) {
+		sessionFiles.append(QFileInfo(sArg).absoluteFilePath());
 	}
 
 #else
 
+	int iCmdArgs = 0;
+
 	QTextStream out(stderr);
 	const QString sEol = "\n\n";
 	const int argc = args.count();
 
 	for (int i = 1; i < argc; ++i) {
 
+		QString sArg = args.at(i);
+
 		if (iCmdArgs > 0) {
-			sSessionFile += " ";
-			sSessionFile += args.at(i);
+			sessionFiles.append(QFileInfo(sArg).absoluteFilePath());
 			++iCmdArgs;
 			continue;
 		}
 
-		QString sArg = args.at(i);
 		QString sVal;
 		const int iEqual = sArg.indexOf("=");
 		if (iEqual >= 0) {
@@ -447,13 +446,12 @@ bool Options::parse_args ( const QStringList& args )
 				.arg(::lscp_client_version());
 			out << QString("%1: %2\n")
 				.arg(QSAMPLER_TITLE)
-				.arg(CONFIG_BUILD_VERSION);
+				.arg(PROJECT_VERSION);
 			return false;
-		}
-		else {
+		} else {
 			// If we don't have one by now,
 			// this will be the startup sesion file...
-			sSessionFile += sArg;
+			sessionFiles.append(QFileInfo(sArg).absoluteFilePath());
 			++iCmdArgs;
 		}
 	}
