@@ -1,7 +1,7 @@
 // qsamplerOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2004-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2024, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007,2008,2015 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -61,8 +61,8 @@ public:
 	void print_usage(const QString& arg0);
 #endif
 
-	// Startup supplied session file.
-	QString sSessionFile;
+	// Startup supplied session file(s).
+	QStringList sessionFiles;
 
 	// Server options...
 	QString sServerHost;
